Datalevin database adapter for Fulcro RAD.
This namespace provides the main public API by re-exporting functions from the modular sub-namespaces. Import this namespace and use its functions to work with the Datalevin adapter.
Main functions:
Datalevin database adapter for Fulcro RAD. This namespace provides the main public API by re-exporting functions from the modular sub-namespaces. Import this namespace and use its functions to work with the Datalevin adapter. Main functions: - start-databases: Start database connections - stop-databases: Stop database connections - pathom-plugin: Create a Pathom3 plugin for database access - generate-resolvers: Generate automatic resolvers for RAD attributes - wrap-datalevin-save: Middleware for saving forms - wrap-datalevin-delete: Middleware for deleting entities - automatic-schema: Generate Datalevin schema from RAD attributes
Options and configuration keys for Datalevin database adapter.
Options and configuration keys for Datalevin database adapter.
Resolver generation for Datalevin database adapter.
Resolver generation for Datalevin database adapter.
Pathom environment wiring for the Datalevin database adapter.
This namespace has NO hard dependency on any Pathom version:
wrap-env is a plain (fn [env] env') augmentor. It is the idiomatic
Pathom 3 integration point — compose it into the env-middleware you
pass to RAD's com.fulcrologic.rad.pathom3/new-processor (alongside
attr/wrap-env and form/wrap-env).pathom-plugin wraps that same augmentation in a Pathom 2
::p/wrap-parser plugin map (a plain namespaced keyword literal — no
pathom require needed), for use with com.fulcrologic.rad.pathom/new-parser.Pathom environment wiring for the Datalevin database adapter. This namespace has NO hard dependency on any Pathom version: - `wrap-env` is a plain `(fn [env] env')` augmentor. It is the idiomatic **Pathom 3** integration point — compose it into the `env-middleware` you pass to RAD's `com.fulcrologic.rad.pathom3/new-processor` (alongside `attr/wrap-env` and `form/wrap-env`). - `pathom-plugin` wraps that same augmentation in a **Pathom 2** `::p/wrap-parser` plugin map (a plain namespaced keyword literal — no pathom require needed), for use with `com.fulcrologic.rad.pathom/new-parser`.
Database lifecycle management for Datalevin adapter.
Database lifecycle management for Datalevin adapter.
Utility functions for Datalevin adapter - query helpers.
Utility functions for Datalevin adapter - query helpers.
Delete form middleware for Datalevin database adapter.
Delete form middleware for Datalevin database adapter.
Save form middleware for Datalevin database adapter.
Save form middleware for Datalevin database adapter.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |