us.whitford.fulcro.rad.database-adapters.datalevin.utilities

Utility functions for Datalevin adapter - query helpers.

Utility functions for Datalevin adapter - query helpers.
raw docstring

pullclj

(pull db pattern eid)

Pull entity data from the database. Convenience wrapper around datalevin.core/pull.

Pull entity data from the database.
Convenience wrapper around datalevin.core/pull.
sourceraw docstring

pull-manyclj

(pull-many db pattern eids)

Pull multiple entities from the database. Convenience wrapper around datalevin.core/pull-many.

Pull multiple entities from the database.
Convenience wrapper around datalevin.core/pull-many.
sourceraw docstring

qclj

(q query & args)

Execute a Datalog query against the database. Convenience wrapper around datalevin.core/q.

Execute a Datalog query against the database.
Convenience wrapper around datalevin.core/q.
sourceraw docstring

seed-database!clj

(seed-database! conn data)

Seed a database with initial data.

Arguments:

  • conn: Datalevin connection
  • data: vector of entity maps to transact

Returns the transaction result.

Seed a database with initial data.

Arguments:
- conn: Datalevin connection
- data: vector of entity maps to transact

Returns the transaction result.
sourceraw docstring

vec-attr-domainclj

(vec-attr-domain qualified-key)

Convert a qualified keyword to a Datalevin vector domain string. Matches datalevin.vector/attr-domain: replaces '/' with '_' (each :db.type/vec attribute is automatically its own vector search domain).

Convert a qualified keyword to a Datalevin vector domain string.
Matches datalevin.vector/attr-domain: replaces '/' with '_' (each
:db.type/vec attribute is automatically its own vector search domain).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries