Utility functions for Datalevin adapter - query helpers.
Utility functions for Datalevin adapter - query helpers.
(pull db pattern eid)Pull entity data from the database. Convenience wrapper around datalevin.core/pull.
Pull entity data from the database. Convenience wrapper around datalevin.core/pull.
(pull-many db pattern eids)Pull multiple entities from the database. Convenience wrapper around datalevin.core/pull-many.
Pull multiple entities from the database. Convenience wrapper around datalevin.core/pull-many.
(q query & args)Execute a Datalog query against the database. Convenience wrapper around datalevin.core/q.
Execute a Datalog query against the database. Convenience wrapper around datalevin.core/q.
(seed-database! conn data)Seed a database with initial data.
Arguments:
Returns the transaction result.
Seed a database with initial data. Arguments: - conn: Datalevin connection - data: vector of entity maps to transact Returns the transaction result.
(vec-attr-domain qualified-key)Convert a qualified keyword to a Datalevin vector domain string. Matches datalevin.vector/attr-domain: replaces '/' with '_' (each :db.type/vec attribute is automatically its own vector search domain).
Convert a qualified keyword to a Datalevin vector domain string. Matches datalevin.vector/attr-domain: replaces '/' with '_' (each :db.type/vec attribute is automatically its own vector search domain).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |